#[unsafe(no_mangle)]pub extern "C" fn hyper_clientconn_handshake(
io: *mut hyper_io,
options: *mut hyper_clientconn_options,
) -> *mut hyper_taskAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Creates an HTTP client handshake task.
Both the io and the options are consumed in this function call.
They should not be used or freed afterwards.
The returned task must be polled with an executor until the handshake completes, at which point the value can be taken.
To avoid a memory leak, the task must eventually be consumed by
hyper_task_free, or taken ownership of by hyper_executor_push
without subsequently being given back by hyper_executor_poll.