#[unsafe(no_mangle)]pub extern "C" fn hyper_clientconn_options_new() -> *mut hyper_clientconn_optionsAvailable on crate feature
ffi and hyper_unstable_ffi only.Expand description
Creates a new set of HTTP clientconn options to be used in a handshake.
To avoid a memory leak, the options must eventually be consumed by
hyper_clientconn_options_free or hyper_clientconn_handshake.